@@ -8,16 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@pepperize/cdk-security-group",
-    "0.0.0",
+    "0.0.38",
     __name__[0:-6],
-    "cdk-security-group@0.0.0.jsii.tgz",
+    "cdk-security-group@0.0.38.jsii.tgz",
 )
 
 __all__ = [
